.. _math_numbers:

Number Systems
==============

There are a number of different collections (called sets) of number that are in use
all over mathematics.

Natural Numbers
---------------

The so called counting numbers, the set of natural numbers contains all the positive
whole numbers and is referred to by the symbol :math:`\mathbb{N}`.

.. math::

   \mathbb{N} = \{0, 1, 2, 3, 4, 5, \ldots\}

.. note::

   There is some `debate`_ over whether :math:`0` should be considered a natural number.
   So you may see the symbol :math:`\mathbb{N}_0` when someone wants to be explicit
   that they consider :math:`0` to be a natural number.


Integers
--------

The integers is the set of all positive and negative whole numbers including 0 and is
referred to by the symbol :math:`\mathbb{Z}`

.. math::

   \mathbb{Z} = \{ \ldots, -2, -1, 0, 1, 2, \ldots \}


.. _debate: https://arxiv.org/abs/1102.0418
